@@ -44,7 +44,7 @@ class Newton:
         file_name = os.path.basename(file_path)
         files = dict(project_id=(None, project_id), upfile=(file_name, open(file_path, 'rb'), mime_type))
         if annotations is not None:
-            files.update(annotations=annotations)
+            files.update(annotations=(None, annotations))
 
         headers = self.__headers.copy()
         del headers['Content-Type']
